@@ -22,7 +22,7 @@ func (c *tmplctx) Env() map[string]string {
 }
 
 // createTmplContext reads the datasources for the given aliases
-func createTmplContext(ctx context.Context, aliases []string, d *data.Data) (interface{}, error) {
+func createTmplContext(_ context.Context, aliases []string, d *data.Data) (interface{}, error) {
 	var err error
 	tctx := &tmplctx{}
 	for _, a := range aliases {
