@@ -19,12 +19,12 @@ func setupInputDirTest(t *testing.T) *fs.Dir {
 out/{{ .in | strings.ReplaceAll $f (index .filemap $f) }}.out
 `),
 		fs.WithDir("in",
-			fs.WithFile("eins.txt", `{{ (ds "config").one }}`, fs.WithMode(0644)),
+			fs.WithFile("eins.txt", `{{ (ds "config").one }}`, fs.WithMode(0o644)),
 			fs.WithDir("inner",
-				fs.WithFile("deux.txt", `{{ (ds "config").two }}`, fs.WithMode(0444)),
+				fs.WithFile("deux.txt", `{{ (ds "config").two }}`, fs.WithMode(0o444)),
 			),
-			fs.WithFile("drei.sh", `#!/bin/sh\necho "hello world"\n`, fs.WithMode(0755)),
-			fs.WithFile("vier.txt", `{{ (ds "config").two }} * {{ (ds "config").two }}`, fs.WithMode(0544)),
+			fs.WithFile("drei.sh", `#!/bin/sh\necho "hello world"\n`, fs.WithMode(0o755)),
+			fs.WithFile("vier.txt", `{{ (ds "config").two }} * {{ (ds "config").two }}`, fs.WithMode(0o544)),
 		),
 		fs.WithDir("out"),
 		fs.WithDir("bad_in",
@@ -59,10 +59,10 @@ func TestInputDir_InputDir(t *testing.T) {
 		content string
 		mode    os.FileMode
 	}{
-		{tmpDir.Join("out", "eins.txt"), "eins", 0644},
-		{tmpDir.Join("out", "inner", "deux.txt"), "deux", 0444},
-		{tmpDir.Join("out", "drei.sh"), `#!/bin/sh\necho "hello world"\n`, 0755},
-		{tmpDir.Join("out", "vier.txt"), "deux * deux", 0544},
+		{tmpDir.Join("out", "eins.txt"), "eins", 0o644},
+		{tmpDir.Join("out", "inner", "deux.txt"), "deux", 0o444},
+		{tmpDir.Join("out", "drei.sh"), `#!/bin/sh\necho "hello world"\n`, 0o755},
+		{tmpDir.Join("out", "vier.txt"), "deux * deux", 0o544},
 	}
 	for _, v := range testdata {
 		info, err := os.Stat(v.path)
@@ -98,10 +98,10 @@ func TestInputDir_InputDirWithModeOverride(t *testing.T) {
 		content string
 		mode    os.FileMode
 	}{
-		{tmpDir.Join("out", "eins.txt"), "eins", 0601},
-		{tmpDir.Join("out", "inner", "deux.txt"), "deux", 0601},
-		{tmpDir.Join("out", "drei.sh"), `#!/bin/sh\necho "hello world"\n`, 0601},
-		{tmpDir.Join("out", "vier.txt"), "deux * deux", 0601},
+		{tmpDir.Join("out", "eins.txt"), "eins", 0o601},
+		{tmpDir.Join("out", "inner", "deux.txt"), "deux", 0o601},
+		{tmpDir.Join("out", "drei.sh"), `#!/bin/sh\necho "hello world"\n`, 0o601},
+		{tmpDir.Join("out", "vier.txt"), "deux * deux", 0o601},
 	}
 	for _, v := range testdata {
 		info, err := os.Stat(v.path)
@@ -136,10 +136,10 @@ func TestInputDir_OutputMapInline(t *testing.T) {
 		content string
 		mode    os.FileMode
 	}{
-		{tmpDir.Join("OUT", "EINS.TXT"), "eins", 0644},
-		{tmpDir.Join("OUT", "INNER", "DEUX.TXT"), "deux", 0444},
-		{tmpDir.Join("OUT", "DREI.SH"), `#!/bin/sh\necho "hello world"\n`, 0755},
-		{tmpDir.Join("OUT", "VIER.TXT"), "deux * deux", 0544},
+		{tmpDir.Join("OUT", "EINS.TXT"), "eins", 0o644},
+		{tmpDir.Join("OUT", "INNER", "DEUX.TXT"), "deux", 0o444},
+		{tmpDir.Join("OUT", "DREI.SH"), `#!/bin/sh\necho "hello world"\n`, 0o755},
+		{tmpDir.Join("OUT", "VIER.TXT"), "deux * deux", 0o544},
 	}
 	for _, v := range testdata {
 		info, err := os.Stat(v.path)
@@ -176,10 +176,10 @@ func TestInputDir_OutputMapExternal(t *testing.T) {
 		content string
 		mode    os.FileMode
 	}{
-		{tmpDir.Join("out", "uno.out"), "eins", 0644},
-		{tmpDir.Join("out", "inner", "dos.out"), "deux", 0444},
-		{tmpDir.Join("out", "tres.out"), `#!/bin/sh\necho "hello world"\n`, 0755},
-		{tmpDir.Join("out", "quatro.out"), "deux * deux", 0544},
+		{tmpDir.Join("out", "uno.out"), "eins", 0o644},
+		{tmpDir.Join("out", "inner", "dos.out"), "deux", 0o444},
+		{tmpDir.Join("out", "tres.out"), `#!/bin/sh\necho "hello world"\n`, 0o755},
+		{tmpDir.Join("out", "quatro.out"), "deux * deux", 0o544},
 	}
 	for _, v := range testdata {
 		info, err := os.Stat(v.path)
@@ -251,9 +251,9 @@ func TestInputDir_InputDirCwd(t *testing.T) {
 		content string
 		mode    os.FileMode
 	}{
-		{tmpDir.Join("in", "eins.out"), "eins", 0644},
-		{tmpDir.Join("in", "inner", "deux.out"), "deux", 0444},
-		{tmpDir.Join("in", "vier.out"), "deux * deux", 0544},
+		{tmpDir.Join("in", "eins.out"), "eins", 0o644},
+		{tmpDir.Join("in", "inner", "deux.out"), "deux", 0o444},
+		{tmpDir.Join("in", "vier.out"), "deux * deux", 0o544},
 	}
 	for _, v := range testdata {
 		info, err := os.Stat(v.path)
